package
module
Version:
v0.0.3
Opens a new window with list of versions in this module.
Published: Dec 5, 2022
License: MIT
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
README
¶
Notify
Golang 推送通知 SDK (钉钉群机器人、飞书群机器人、企业微信群机器人、邮件)。
支持的平台
安装
环境要求
引入本包
go get -u github.com/mohuani/notify
使用
钉钉机器人
前置准备
请先阅读一遍官方的文档 钉钉群机器人,熟悉里面的各种名词概念。
调用
// Text Message
// Link Message
// Markdown Message
// Feed Card Message
// Single Action Card Message
// Btns Action Card Message
特别感谢
本项目借鉴了下面开源项目的思路,在此表示感谢,排名不分先后。
License
MIT
Documentation
¶
type IClient interface {
Send(msg any) error
}
Source Files
¶
Directories
¶
dingtalk
|
|
|
|
|
|
|
|
feishu
|
|
|
|
|
|
|
|
Click to show internal directories.
Click to hide internal directories.